@@ -1,10 +1,8 @@
 package Deeme::Backend;
 use Deeme::Obj -base;
-use B::Deparse;
 use Carp 'croak';
 
 has 'deeme';
-has 'deparse' => sub { B::Deparse->new };
 
 sub events_get {
     croak 'Method "events_get" not implemented by subclass';
@@ -35,3 +33,35 @@ sub event_update {
 }    #update event
 
 1;
+
+__END__
+=encoding utf-8
+
+=head1 NAME
+
+Deeme::Backend - Database backend base class for Deeme
+
+=head1 SYNOPSIS
+
+  use Deeme::Obj "Deeme::Backend";
+
+=head1 DESCRIPTION
+
+Deeme::Backend is the base class used by the implemented backends
+
+=head1 AUTHOR
+
+mudler E<lt>mudler@dark-lab.netE<gt>
+
+=head1 COPYRIGHT
+
+Copyright 2014- mudler
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 SEE ALSO
+
+=cut
